pkgname <- "MODIStsp"
source(file.path(R.home("share"), "R", "examples-header.R"))
options(warn = 1)
library('MODIStsp')

base::assign(".oldSearch", base::search(), pos = 'CheckExEnv')
base::assign(".old_wd", base::getwd(), pos = 'CheckExEnv')
cleanEx()
nameEx("MODIStsp")
### * MODIStsp

flush(stderr()); flush(stdout())

### Name: MODIStsp
### Title: MODIStsp main function
### Aliases: MODIStsp

### ** Examples




cleanEx()
nameEx("MODIStsp_addindex")
### * MODIStsp_addindex

flush(stderr()); flush(stdout())

### Name: MODIStsp_addindex
### Title: Add custom spectral indexes
### Aliases: MODIStsp_addindex

### ** Examples

# Run the GUI to interactively define a new index
 ## Not run: 
##D  MODIStsp_addindex()
## End(Not run)

# Define the new index in non-interactive execution

## Not run: 
##D MODIStsp_addindex(new_indexbandname = "SSI",
##D   new_indexfullname = "Simple Useless Index",
##D   new_indexformula = "b2_NIR+b1_Red")
## End(Not run)



cleanEx()
nameEx("MODIStsp_extract")
### * MODIStsp_extract

flush(stderr()); flush(stdout())

### Name: MODIStsp_extract
### Title: Extract data from MODIStsp time series
### Aliases: MODIStsp_extract

### ** Examples

## Not run: 
##D # Extract average and standard deviation values from a rts object created by
##D # MODIStsp for each polygon of a shapefile, for each date in the period
##D # between 2001-01-01 and 2014-12-31
##D 
##D # The example uses tif files in testdata/VI_16Days_500m_v6 to build
##D # a MODIStsp rasterStack corresponding to the 2016 time series of the NDVI index
##D # over the Como Lake (Italy). It then extracts data on polygons corresponding
##D # to different land cover classes saved in testdata/extract_polys.shp
##D 
##D # First, prepare the test dataset.
##D # __NOTE__ To avoid redownloading, here we copy some test data from MODIStsp
##D # installation folder to tempdir and use it to create a test time series.
##D 
##D test_zip <-  system.file("testdata/VI_16Days_500m_v6/NDVI.zip",
##D                          package = "MODIStsp")
##D dir.create(file.path(tempdir(), "MODIStsp/VI_16Days_500m_v6"),
##D            showWarnings = FALSE, recursive = TRUE)
##D utils::unzip(test_zip, 
##D              exdir = file.path(tempdir(), "MODIStsp/VI_16Days_500m_v6"))
##D 
##D opts_file <- system.file("testdata/test_extract.json", package = "MODIStsp")
##D MODIStsp(opts_file = opts_file, gui = FALSE, verbose = FALSE)
##D 
##D # Now load the MODIStsp stack: This is a MODIS NDVI time series ranging between
##D # 2016-01-01 and 2016-12-18
##D # __NOTE__: MODIStsp rasterStack files are always saved in the "Time_Series\/RData"
##D # subfolder of your main output folder - see
##D # "https://docs.ropensci.org/MODIStsp/articles/output.html")
##D 
##D # Specify the filename of the RData RasterStack of interest
##D stack_file  <- file.path(tempdir(),
##D  "MODIStsp/VI_16Days_500m_v6/Time_Series/RData/Terra/NDVI",
##D   "MOD13A1_NDVI_1_2016_353_2016_RData.RData")
##D basename(stack_file)
##D 
##D ts_data <- get(load(stack_file))
##D ts_data
##D 
##D # Now load a shapefile containing polygons from which we want to extract data
##D 
##D polygons <- sf::st_read(system.file("testdata/extract_polys.shp",
##D                            package = "MODIStsp"), quiet = TRUE)
##D polygons
##D 
##D # Finally, extract the average values for each polygon and date and plot the
##D # results
##D 
##D out_dataavg <- suppressMessages(MODIStsp_extract(ts_data, polygons, id_field = "lc_type",
##D                              small = FALSE))
##D head(out_dataavg)
##D 
##D plot(out_dataavg, legend.loc = "topleft")
##D 
##D # use a different summarization function
##D 
##D out_datasd <- MODIStsp_extract(ts_data, polygons, id_field = "lc_type",
##D                               FUN = "sd", small = FALSE)
##D head(out_datasd)
##D 
##D # (See also https://docs.ropensci.org/MODIStsp/articles/Analyze.html for a
##D # worked-out example)
## End(Not run)



cleanEx()
nameEx("MODIStsp_get_prodlayers")
### * MODIStsp_get_prodlayers

flush(stderr()); flush(stdout())

### Name: MODIStsp_get_prodlayers
### Title: Retrieve the names of MODIS layers for a product
### Aliases: MODIStsp_get_prodlayers

### ** Examples


# Get layers of product M*13Q1 based on code
MODIStsp_get_prodlayers("M*13Q1")

# Get layers of product M*13Q1 based on full name
MODIStsp_get_prodlayers("Vegetation Indexes_16Days_250m (M*D13Q1)")

# Get indexes names of product M*13Q1 based on full name
MODIStsp_get_prodlayers("MCD43C4")$indexes_bandnames





cleanEx()
nameEx("MODIStsp_get_prodnames")
### * MODIStsp_get_prodnames

flush(stderr()); flush(stdout())

### Name: MODIStsp_get_prodnames
### Title: Retrieve the names of all available product
### Aliases: MODIStsp_get_prodnames

### ** Examples

# Get MODIStsp product names
MODIStsp_get_prodnames()



cleanEx()
nameEx("MODIStsp_resetindexes")
### * MODIStsp_resetindexes

flush(stderr()); flush(stdout())

### Name: MODIStsp_resetindexes
### Title: Remove custom spectral indexes
### Aliases: MODIStsp_resetindexes

### ** Examples

## Not run: 
##D # Remove all custom-defined spectral indexes from an options file
##D 
##D # Add a custom index for testing purposes
##D library(jsonlite)
##D opts_jsfile = system.file("testdata/test_addindex.json",
##D                              package = "MODIStsp")
##D  MODIStsp_addindex(
##D    opts_jsfile = opts_jsfile,
##D    gui = FALSE,
##D    new_indexbandname = paste0("Index_", as.character(sample(10000, 1))),
##D    new_indexformula = "b1_Red - b2_NIR",
##D    new_indexfullname = paste0("Index_", as.character(sample(10000, 1)))
##D    )
##D 
##D  opts <- jsonlite::fromJSON(indexes_file)
##D  opts$custom_indexes[1]
##D 
##D  # Now remove all custom indexes
##D  MODIStsp_resetindexes()
##D  opts <- jsonlite::fromJSON(opts_jsfile)
##D  opts$custom_indexes[1]
##D  
## End(Not run)




cleanEx()
nameEx("check_projection")
### * check_projection

flush(stderr()); flush(stdout())

### Name: check_projection
### Title: Check the validity of the input projection
### Aliases: check_projection check_projection.default
###   check_projection.numeric check_projection.character
###   check_projection.crs

### ** Examples


## Not run: 
##D check_projection("32632")
##D 
##D check_projection("32631")
##D 
##D check_projection(32633)
##D 
##D check_projection(30, abort = FALSE)
##D 
##D check_projection("example of invalid string", abort = FALSE)
##D 
##D proj_wkt <- sf::st_as_text(sf::st_crs(32632))
##D check_projection(proj_wkt)
## End(Not run)



cleanEx()
nameEx("install_MODIStsp_launcher")
### * install_MODIStsp_launcher

flush(stderr()); flush(stdout())

### Name: install_MODIStsp_launcher
### Title: Install a launcher for MODIStsp
### Aliases: install_MODIStsp_launcher

### ** Examples

# Linux: common installation (script in /usr/bin,
# desktop entry in /usr/share/applications)
# (requires administrator permissions)
## Not run: 
##D # the administrator password is asked interactively
##D install_MODIStsp_launcher(sudo = TRUE)
## End(Not run)

# Linux: installation in a directory which does not require administrator
# permissions
## Not run: 
##D install_MODIStsp_launcher(bin_dir = "~/bin", desktop_dir = "~/Desktop")
## End(Not run)

# Windows: common installation
# (script in the Start Menu and shortcut on the desktop)
## Not run: 
##D install_MODIStsp_launcher()
## End(Not run)



cleanEx()
nameEx("split_nodata_values")
### * split_nodata_values

flush(stderr()); flush(stdout())

### Name: split_nodata_values
### Title: Split NODATA values or create matrix for reclassification
### Aliases: split_nodata_values create_nodata_rcl

### ** Examples

MODIStsp:::create_nodata_rcl(c("255","250,254:255"), c("255","255"))



### * <FOOTER>
###
cleanEx()
options(digits = 7L)
base::cat("Time elapsed: ", proc.time() - base::get("ptime", pos = 'CheckExEnv'),"\n")
grDevices::dev.off()
###
### Local variables: ***
### mode: outline-minor ***
### outline-regexp: "\\(> \\)?### [*]+" ***
### End: ***
quit('no')
